/*
 * Fisoco : FInd, Select, Order and COnvert files
 * Copyright 2016 (C) Felicien PILLOT <felicien.pillot@member.fsf.org>
 * 
 * This file is part of Fisoco.
 * 
 * Fisoco is free software: you can redistribute it and/or modify
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Fisoco is distributed in the hope that it will be useful,
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * with Fisoco.  If not, see <http://www.gnu.org/licenses/>.
 *//////////////////////////////////////
/***********
 * global.h *
 * ~~~~~~~~ *
 ************/

#ifndef FISOCO_GLOBAL_H
#define FISOCO_GLOBAL_H

#if HAVE_CONFIG_H
#  include <config.h>
#endif /* HAVE_CONFIG_H */
#if HAVE_UNISTD_H
#  include <unistd.h>
#endif /* HAVE_UNISTD_H */
#include <iostream>
// i18n
#include "gettext.h"

void activate_debug (bool state);
void debug (std::string message);
void error (std::string message);
void goodnews (std::string message);
void help ();
void version ();

extern bool debug_ok;

#endif // FISOCO_GLOBAL_H

